bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: GaussianGammaToGaussianWishart

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaToGaussianWishart.__init__
      ~GaussianGammaToGaussianWishart.add_plate_axis
      ~GaussianGammaToGaussianWishart.broadcasting_multiplier
      ~GaussianGammaToGaussianWishart.delete
      ~GaussianGammaToGaussianWishart.get_mask
      ~GaussianGammaToGaussianWishart.get_moments
      ~GaussianGammaToGaussianWishart.get_shape
      ~GaussianGammaToGaussianWishart.has_plotter
      ~GaussianGammaToGaussianWishart.lower_bound_contribution
      ~GaussianGammaToGaussianWishart.move_plates
      ~GaussianGammaToGaussianWishart.plot
      ~GaussianGammaToGaussianWishart.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianGammaToGaussianWishart.plates
      ~GaussianGammaToGaussianWishart.plates_multiplier
   
   